==> apache-drill-1.21.2-src.tar.gz: apache-drill-1.21.2-src/exec/java-exec/src/main/java/org/apache/drill/exec/coord/zk/ZkTransientStoreFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.coord.zk;

import org.apache.drill.shaded.guava.com.google.common.base.Preconditions;
import org.apache.curator.framework.CuratorFramework;
import org.apache.drill.common.exceptions.DrillRuntimeException;
import org.apache.drill.exec.coord.store.TransientStoreConfig;
import org.apache.drill.exec.coord.store.TransientStoreFactory;

public class ZkTransientStoreFactory implements TransientStoreFactory {

  private final CuratorFramework curator;

  public ZkTransientStoreFactory(final CuratorFramework curator) {
    this.curator = Preconditions.checkNotNull(curator, "curator is required");
  }

  @Override
  public <V> ZkEphemeralStore<V> getOrCreateStore(TransientStoreConfig<V> config) {
    final ZkEphemeralStore<V> store = new ZkEphemeralStore<>(config, curator);
    try {
      store.start();
    } catch (final Exception e) {
      throw new DrillRuntimeException("unable to start zookeeper transient store", e);
    }
    return store;
  }

  @Override
  public void close() throws Exception {

  }
}

==> apache-drill-1.22.0-src.tar.gz: apache-drill-1.22.0-src/exec/java-exec/src/main/java/org/apache/drill/exec/coord/zk/ZkTransientStoreFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.coord.zk;

import com.google.common.base.Preconditions;
import org.apache.curator.framework.CuratorFramework;
import org.apache.drill.common.exceptions.DrillRuntimeException;
import org.apache.drill.exec.coord.store.TransientStoreConfig;
import org.apache.drill.exec.coord.store.TransientStoreFactory;

public class ZkTransientStoreFactory implements TransientStoreFactory {

  private final CuratorFramework curator;

  public ZkTransientStoreFactory(final CuratorFramework curator) {
    this.curator = Preconditions.checkNotNull(curator, "curator is required");
  }

  @Override
  public <V> ZkEphemeralStore<V> getOrCreateStore(TransientStoreConfig<V> config) {
    final ZkEphemeralStore<V> store = new ZkEphemeralStore<>(config, curator);
    try {
      store.start();
    } catch (final Exception e) {
      throw new DrillRuntimeException("unable to start zookeeper transient store", e);
    }
    return store;
  }

  @Override
  public void close() throws Exception {

  }
}
